<?php
/* $Id: japanese-sjis.inc.php 11122 2008-02-13 12:33:49Z lem9 $ */

/**
 * Translated by Yukihiro Kawada <kawada at den.fujifilm.co.jp>
 *               Tadashi Jokagi <elf2000 at users.sourceforge.net>
 *               Kenichi Ishigaki <ishigaki at tcool.org>
 */

$charset = 'shift_jis';
$text_dir = 'ltr';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('oCg', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB');

$mysql_4_1_doc_lang = 'ja';

$day_of_week = array('', '', '', '', '', '', 'y');
$month = array('1 ','2 ','3 ','4 ','5 ','6 ','7 ','8 ','9 ','10 ','11 ','12 ');
// See http://www.php.net/manual/ja/function.strftime.php to define the
// variable below
$datefmt = '%Y N %B %d  %H:%M';
$timespanfmt = '%s  %s  %s  %s b';

$strAbortedClients = 'f';
$strAccessDenied = 'ANZX͋ۂ܂';
$strAccessDeniedCreateConfig = 'ݒt@C쐬ĂȂ̂Ǝv܂B%1$sZbgAbvXNvg%2$s 𗘗pĐݒt@C쐬Ă';
$strAccessDeniedExplanation = 'MySQL T[oɐڑ悤Ƃ܂ۂ܂Bconfig.inc.php ̃zXgA[UApX[h MySQL T[o̊Ǘ҂^ꂽƈv邩mFĂ';
$strAction = '';
$strAddAutoIncrement = 'AUTO_INCREMENT lǉ';
$strAddClause = '%sǉ';
$strAddConstraints = 'ǉ';
$strAddDeleteColumn = 'tB[hǉE폜';
$strAddDeleteRow = 'sǉE폜';
$strAddFields = '%s ̃tB[hǉ';
$strAddHeaderComment = 'wb_ɃJX^Rgǉ (\\n ŉs)';
$strAddIntoComments = 'ǉRg';
$strAddNewField = 'VKtB[hǉ';
$strAddPrivilegesOnDb = 'f[^x[Xɓǉ';
$strAddPrivilegesOnTbl = 'e[uɓǉ';
$strAddSearchConditions = '("where"߂̓e)ǉĂ:';
$strAddToIndex = 'CfbNX&nbsp;%s&nbsp; ̗ǉ܂';
$strAddUserMessage = 'V[Uǉ܂';
$strAddUser = 'V[Uǉ';
$strAdministration = 'Ǘ';
$strAffectedRows = 'ύXꂽs:';
$strAfterInsertBack = 'Õy[Wɖ߂';
$strAfterInsertNewInsert = 'VR[hǉ';
$strAfterInsertNext = '̍sҏW';
$strAfterInsertSame = '̃y[Wɖ߂';
$strAfter = 'wJ̌ %s';
$strAllowInterrupt = 'Ԃ߂ȂƂɃXNvgŃC|[g𒆒fł悤ɂ܂B傫ȃt@CC|[gꍇɂ͕֗łAgUNV邱Ƃ܂';
$strAll = 'S';
$strAllTableSameWidth = 'ׂẴe[u𓯂ŕ\\܂?';
$strAlterOrderBy = 'e[u̕я';
$strAnalyzeTable = 'e[u𕪐͂';
$strAnd = 'AND';
$strAndThen = '';
$strAngularLinks = 'pN';
$strAnIndex = '%s ɃCfbNXǉ܂';
$strAny = 'ׂ';
$strAnyHost = 'ׂẴzXg';
$strAnyUser = 'ׂẴ[U';
$strApproximateCount = 'mȐƂ͌܂BFAQ 3.11 ';
$strAPrimaryKey = '%s ɎL[ǉ܂';
$strArabic = 'ArA';
$strArmenian = 'AjA';
$strAscending = '';
$strAtBeginningOfTable = 'e[u̐擪';
$strAtEndOfTable = 'e[u̖';
$strAttr = '';
$strAutomaticLayout = 'CAEg';

$strBack = '߂';
$strBaltic = 'og';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinaryDoNotEdit = ' oCi - ҏWs';
$strBinaryLog = 'oCiO';
$strBinary = ' oCi';
$strBinLogEventType = 'Cxg';
$strBinLogInfo = '';
$strBinLogName = 'O';
$strBinLogOriginalPosition = '̈ʒu';
$strBinLogPosition = 'ʒu';
$strBinLogServerId = 'T[o ID';
$strBookmarkAllUsers = 'ׂẴ[ŨubN}[N𗘗pł悤ɂ';
$strBookmarkCreated = 'ubN}[N %s 쐬܂';
$strBookmarkDeleted = 'ubN}[N폜܂';
$strBookmarkLabel = 'x';
$strBookmarkQuery = 'ubN}[NĂ SQL';
$strBookmarkReplace = '̃ubN}[N͍ւ';
$strBookmarkThis = ' SQL ubN}[N';
$strBookmarkView = '\\̂'; // XXX r[pH
$strBrowseDistinctValues = 'dĂl\\Ȃ'; // XXX
$strBrowseForeignValues = 'QƂĂl\\';
$strBrowse = '\\';
$strBufferPoolActivity = 'obt@v[̗p';
$strBufferPool = 'obt@v[';
$strBufferPoolUsage = 'obt@v[̎gp';
$strBufferReadMisses = 'ǂݍ݃~X';
$strBufferReadMissesInPercent = 'ǂݍ݃~X()';
$strBufferWriteWaitsInPercent = 'ݑ҂()';
$strBufferWriteWaits = 'ݑ҂';
$strBulgarian = 'uKA';
$strBusyPages = 'rW[ȃy[W'; // XXX
$strBzError = '̃o[W PHP  Bz2 gĂ̂Ń_vkł܂BphpMyAdmin ̐ݒt@C <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>ɐݒ肷邱Ƃ܂BBz2 k@\gꍇ PHP ̃o[WグĉBPHP ̃oO|[g %s ';
$strBzip = '"bzip `"';

$strCalendar = 'J_[';
$strCancel = 'LZ';
$strCanNotLoadExportPlugins = 'GNX|[gvOC[hł܂BCXg[Ă邩mFĂ!';
$strCanNotLoadImportPlugins = 'C|[gvOC[hł܂BCXg[Ă邩mFĂ!';
$strCannotLogin = 'MySQL T[oɃOCł܂';
$strCantLoad = '[a@http://php.net/%1$s@Documentation][em]%1$s[/em][/a] g[hł܂BPHP ̐ݒmFĂ';
$strCantLoadRecodeIconv = 'Zbg̕ϊɕKv iconv Ȃ GNU recode g[hł܂BPHP ł̊gLɂ邩AphpMyAdmin ŕZbg̕ϊ𖳌ɂĂ';
$strCantRenameIdxToPrimary = 'CfbNX PRIMARY ɕύX邱Ƃ͂ł܂!';
$strCantUseRecodeIconv = 'KvȊg̓[hĂ悤łAiconv  libiconvArecode_string ̊֐𗘗pł܂BPHP ̐ݒmFĂ';
$strCardinality = 'ӂȒl̐';
$strCaseInsensitive = '啶ʂȂ';
$strCaseSensitive = '啶ʂ';
$strCentralEuropean = '[bp';
$strChangeCopyMode = 'V[U';
$strChangeCopyModeCopy = '̃[Uc';
$strChangeCopyModeDeleteAndReload = '[Ue[u猳̃[U폜A[h';
$strChangeCopyModeJustDelete = '[Ue[u猳̃[U폜';
$strChangeCopyModeRevoke = '̃[Uׂ̓ĖɂĂ폜';
$strChangeCopyUser = 'OC̕ύX / [U̕';
$strChangeDisplay = '\\tB[hIĂ';
$strChange = 'ύX';
$strChangePassword = 'pX[hύX';
$strCharsetOfFile = 't@C̕Zbg:';
$strCharsetsAndCollations = 'ZbgƏƍ';
$strCharsets = 'Zbg';
$strCharset = 'Zbg';
$strCheckAll = 'ׂă`FbN';
$strCheckOverhead = 'I[o[wbĥe[umFĂ'; // XXX
$strCheckPrivs = '`FbN';
$strCheckPrivsLong = 'f[^x[X &quot;%s&quot; ̓mFĂ'; // XXX
$strCheckTable = 'e[u`FbN';
$strChoosePage = 'ҏWy[WIĂ';
$strColComFeat = 'Rg\\@\\'; // XXX
$strCollation = 'ƍ';
$strColumnNames = 'J';
$strColumnPrivileges = '̃JɌŗL̓';
$strCommand = 'R}h';
$strCommentsForTable = 'COMMENTS FOR TABLE'; // XXX
$strComments = 'Rg';
$strCompatibleHashing = 'MySQL&nbsp;4.0 ݊';
$strCompleteInserts = 'S INSERT 쐬';
$strCompression = 'k';
$strCompressionWillBeDetected = 'C|[gt@C̈k@͎̒玩o܂: %s';
$strConfigDefaultFileError = 'ftHg̐ݒǂݍ߂܂ł: "%1$s"';
$strConfigFileError = 'phpMyAdmin ̐ݒt@Cǂݍ߂܂ł! <br />@G[At@C܂B<br />̃N璼ڐݒt@Cǂݍ PHP ̃G[bZ[WmFĂBĂ̏ꍇ͂ǂɈpZ~R̔܂B<br />󔒂̃y[W\\ΖȂł';
$strConfigureTableCoord = 'e[u %s ̍Wݒ肵Ă';
$strConnectionError = 'ڑł܂: ݒ肪ł';
$strConnections = 'ڑ';
$strConstraintsForDumped = '_ve[u̐';
$strConstraintsForTable = 'e[u̐';
$strControluserFailed = 'ݒt@Cɒ`ĂǗ[U(controluser)ł̐ڑɎs܂';
$strCookiesRequired = 'NbL[LɂĂ';
$strCopyDatabaseOK = 'f[^x[X %s  %s ɃRs[܂';
$strCopy = 'Rs[';
$strCopyTable = 'e[u(database<b>.</b>table)ɃRs[:';
$strCopyTableOK = 'e[u %s  %s ɃRs[܂';
$strCopyTableSameNames = 'e[uɂ̓Rs[ł܂!';
$strCouldNotKill = 'Xbh %s ̏IɎs܂BłɕĂ悤ł';
$strCreateDatabaseBeforeCopying = 'Rs[̑O CREATE DATABASE ';
$strCreate = '쐬';
$strCreateIndex = '&nbsp;%s&nbsp; ̃JɃCfbNX쐬';
$strCreateIndexTopic = 'VCfbNX쐬';
$strCreateNewDatabase = 'VKf[^x[X쐬';
$strCreateNewTable = 'f[^x[X %s ɐVe[u쐬';
$strCreatePage = 'Vy[W쐬';
$strCreatePdfFeat = 'PDF ̍쐬';
$strCreateRelation = '[V쐬';
$strCreateTable  = 'e[u쐬';
$strCreateUserDatabaseName = '̃f[^x[X쐬ĂׂĂ̓^';
$strCreateUserDatabaseNone = 'Ȃ';
$strCreateUserDatabase = '[Upf[^x[X';
$strCreateUserDatabaseWildcard = 'ChJ[h([U_%)ɊYf[^x[XɂׂĂ̓^';
$strCreationDates = '쐬/XV/';
$strCriteria = '';
$strCroatian = 'NA`A';
$strCSV = 'CSV';
$strCyrillic = 'LVA';
$strCzech = '`FR';
$strCzechSlovak = '`FR̃XoLA';

$strDanish = 'f}[N';
$strDatabaseEmpty = 'f[^x[Xł!';
$strDatabaseExportOptions = 'f[^x[XGNX|[gIvV';
$strDatabase = 'f[^x[X';
$strDatabaseHasBeenDropped = 'f[^x[X %s 폜܂';
$strDatabasesDropped = 'f[^x[X %s 𐳏ɍ폜܂';
$strDatabases = 'f[^x[X';
$strDatabasesStatsDisable = 'v𖳌ɂ';
$strDatabasesStatsEnable = 'vLɂ';
$strDatabasesStats = 'f[^x[X̓v';
$strDatabasesStatsHeavyTraffic = ': f[^x[X̓vLɂƃEFuT[o MySQL T[o̊Ԃ̒ʐMʂ邱Ƃ܂';
$strDataDict = 'f[^';
$strData = 'f[^';
$strDataOnly = 'f[^̂';
$strDataPages = 'f[^܂܂Ăy[W';
$strDBComment = 'f[^x[X̃Rg:';
$strDBCopy = 'f[^x[X̃Rs[';
$strDbIsEmpty = 'f[^x[X̂悤ł!';
$strDbPrivileges = 'f[^x[XɌŗL̓';
$strDBRename = 'Vf[^x[X';
$strDbSpecific = 'f[^x[XŗL';
$strDefaultEngine = '%s ͂ MySQL T[õftHgXg[WGWł';
$strDefault = 'ftHgl';
$strDefaultValueHelp = 'ftHglɂ͂ЂƂ̒l̂ݓ͂ĂBobNXbVɂGXP[vp܂߂邱Ƃ͂ł܂B: a';
$strDefragment = 'e[ũftO';
$strDelayedInserts = 'xCT[ggp';
$strDeleteAndFlushDescr = '͂ƂN[ȕ@łÃ[hɎԂ邱Ƃ܂';
$strDeleteAndFlush = '[U폜ē[h';
$strDeletedRows = '폜s:';
$strDeleted = 's폜܂';
$strDelete = '폜';
$strDeleteNoUsersSelected = '폜郆[UIĂ܂!';
$strDeleteRelation = '[V폜';
$strDeleting = '%s 폜ł';
$strDelimiter = 'f~^';
$strDelOld = '̃y[Wɂ݂͑Ȃe[uւ̎QƂ܂B̎QƂ폜܂?';
$strDescending = '~';
$strDescription = '';
$strDesigner = 'fUCi';
$strDesignerHelpDisplayField = '\\tB[h̓sNFŕ\\܂B\\\\؂ւꍇ́u\\tB[hIvƂACRNbNĂK؂ȃtB[hNbN';
$strDictionary = '';
$strDirectLinks = 'N';
$strDirtyPages = '_[eBy[W';
$strDisabled = '';
$strDisableForeignChecks = 'OL[̃`FbN𖳌ɂ';
$strDisplayFeat = '\\@\\';
$strDisplayOrder = '\\:';
$strDisplayPDF = 'PDF XL[}\\';
$strDoAQuery = '"query by example"s (ChJ[h: "%")';
$strDocSQL = 'DocSQL';
$strDocu = 'hLg';
$strDoYouReally = '{Ɏs܂?';
$strDropDatabaseStrongWarning = 'f[^x[XSɍ폜悤ƂĂ܂!';
$strDrop = '폜';
$strDropUsersDb = '[UƓ̃f[^x[X폜';
$strDumpingData = 'e[ũf[^_vĂ܂';
$strDumpSaved = '_vt@C %s ɕۑ܂';
$strDumpXRows = '%s s_v܂(Jns: %s)';
$strDynamic = 'I';

$strEdit = 'ҏW';
$strEditPDFPages = 'PDF y[WҏW';
$strEditPrivileges = 'ҏW';
$strEffective = ''; // XXX
$strEmpty = 'ɂ';
$strEmptyResultSet = 'Ԃlł(s0)';
$strEnabled = 'L';
$strEncloseInTransaction = 'GNX|[ggUNVň͂';
$strEncto = 'GR[fBO֕ϊ'; // encoding convert
$strEnd = 'Ō';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEngineAvailable = '%s ͗LɂȂĂ܂';
$strEngineDisabled = '%s ͖ɂȂĂ܂';
$strEngines = 'GW';
$strEngineUnsupported = ' MySQL T[o %s Xg[WGWT|[gĂ܂';
$strEnglish = 'p';
$strEnglishPrivileges = ': MySQL ͉̓pŕ\\܂';
$strError = 'G[';
$strErrorInZipFile = 'ZIP A[JCuɃG[܂:';
$strErrorRelationAdded = 'G[: [Vǉł܂ł';
$strErrorRelationExists = 'G[: [V͂łɑ݂Ă܂';
$strErrorRenamingTable = 'e[u %1$s  %2$s Ƀl[ƂɃG[܂';
$strErrorSaveTable = 'fUCi̍WۑƂɃG[܂';
$strEscapeWildcards = '_  % ƂChJ[h𕶎ƂĎgpƂ \ ŃGXP[vĂ';
$strEsperanto = 'GXyg';
$strEstonian = 'GXgjA';
$strEvent = 'Cxg';
$strExcelEdition = 'Excel ̃GfBV';
$strExecuteBookmarked = 'ubN}[NꂽNGs';
$strExplain = 'EXPLAIN ŊmF';
$strExport = 'GNX|[g';
$strExportImportToScale = '{ɂ킹GNX|[g/C|[g';
$strExportMustBeFile = '̌`̃GNX|[g̓t@CɕۑKv܂!';
$strExtendedInserts = ' INSERT 쐬';
$strExtra = '̑';

$strFailedAttempts = 's';
$strFieldHasBeenDropped = 'tB[h %s 폜܂';
$strFieldInsertFromFileTempDirNotExists = 'Abv[hꂽt@C̈ړɎs܂BFAQ 1.11 B';
$strFieldsEnclosedBy = 'tB[h͂݋L';
$strFieldsEscapedBy = 'tB[h̃GXP[vL';
$strFields = 'tB[h';
$strFieldsTerminatedBy = 'tB[h؂L';
$strField = 'tB[h';
$strFileAlreadyExists = 'T[oɊ̃t@C %s ܂Bt@CύX邩A㏑IvVLɂĂ';
$strFileCouldNotBeRead = 't@Cǂݍ߂܂ł';
$strFileNameTemplateDescriptionDatabase = 'f[^x[X';
$strFileNameTemplateDescription = '̃ev[g %1$sstrftime%2$s gĉ߂܂B̂߁AԂ̏𗘗pł܂B܂A̕ϊs܂B%3$s ȊÕeLXg͏C܂';
$strFileNameTemplateDescriptionServer = 'T[o';
$strFileNameTemplateDescriptionTable = 'e[u';
$strFileNameTemplateRemember = 'ev[gL';
$strFileNameTemplate = 't@C̃ev[g';
$strFiles = 't@C';
$strFileToImport = 'C|[gt@C';
$strFixed = 'Œ';
$strFlushPrivilegesNote = ': phpMyAdmin  MySQL ̓e[u璼ڃ[U擾܂AƂœXVꍇ phpMyAdmin pĂe[u̓eƃT[o̓̓evȂȂ邱Ƃ܂̂ŁAƂ𑱂O %s[h%s Ă';
$strFlushQueryCache = 'NGLbVtbV';
$strFlushTable = 'e[utbV("FLUSH")';
$strFlushTables = 'ׂẴe[utbV()';
$strFontSize = 'tHgTCY';
$strForeignKeyError = 'OL[쐬ɃG[܂ (f[^^mFĂ)';
$strFormat = 'tH[}bg';
$strFormEmpty = 'tH[ɓ͂ĂȂl܂!';
$strFreePages = 't[y[W';
$strFullText = 'S';
$strFunction = '֐';
$strFunctions = '֐';

$strGenBy = '';
$strGeneralRelationFeat = 'ʓIȃ[V@\\';
$strGenerate = '';
$strGeneratePassword = 'pX[h𐶐';
$strGenTime = '';
$strGeorgian = 'OWA';
$strGerman = 'hCc';
$strGlobal = 'O[o';
$strGlobalPrivileges = 'O[o';
$strGlobalValue = 'O[ol';
$strGo = 's';
$strGrantOption = 'Ϗ';
$strGreek = 'MVA';
$strGzip = '"gzip `"';

$strHandler = 'nh';
$strHasBeenAltered = 'ύX܂';
$strHasBeenCreated = '쐬܂';
$strHaveToShow = 'ŒЂƂ͕\\JIĂ';
$strHebrew = 'wuC';
$strHelp = 'wv';
$strHexForBLOB = 'BLOB16i\L𗘗p';
$strHide         = 'B';
$strHideShowAll = 'ׂĉB/\\';
$strHideShowNoRelation = '[V̂Ȃe[uB/\\';
$strHome = 'Cy[W';
$strHomepageOfficial = 'phpMyAdmin ̃ItBVTCg';
$strHostEmpty = 'zXgł!';
$strHost = 'zXg';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'nK[';

$strIcelandic = 'ACXh';
$strId = 'ID';
$strIdxFulltext = 'S';
$strIEUnsupported = 'Internet Explorer ł͂̋@\͗pł܂';
$strIgnore = '';
$strIgnoreDuplicates = 'dĂs𖳎';
$strIgnoreInserts = 'INSERT IGNORE gp';
$strImport = 'C|[g';
$strImportExportCoords = 'PDF XL[}̍WC|[g/GNX|[g';
$strImportFiles = 'C|[gt@C';
$strImportFormat = 'C|[gt@Č`';
$strImportSuccessfullyFinished = 'C|[g͐I܂B%d ̃NGs܂';
$strIndex = 'CfbNX';
$strIndexes = 'CfbNXTCY';
$strIndexesSeemEqual = 'ȉ̃CfbNX͓̂̂悤Ɏv܂Bꂩ폜Ă :';
$strIndexHasBeenDropped = 'CfbNX %s 폜܂';
$strIndexName = 'CfbNX:';
$strIndexType = 'CfbNX̎:';
$strIndexWarningTable = 'e[u `%s` ̃CfbNXɖ肪܂';
$strInnoDBAutoextendIncrementDesc = 'Xy[XςɂȂƂɎIɃe[ugꍇɒǉe[uTCY';
$strInnoDBAutoextendIncrement = 'gɒǉe[uTCY';
$strInnoDBBufferPoolSizeDesc = 'InnoDB e[ũf[^CfbNXLbV̂Ɏgobt@';
$strInnoDBBufferPoolSize = 'obt@v[̃TCY';
$strInnoDBDataFilePath = 'f[^t@C';
$strInnoDBDataHomeDirDesc = 'ׂĂ InnoDB f[^t@CɋʂfBNgpX';
$strInnoDBDataHomeDir = 'f[^̃z[fBNg';
$strInnoDBPages = 'y[W';
$strInnoDBRelationAdded = 'InnoDB [Vǉ܂';
$strInnodbStat = 'InnoDB Xe[^X';
$strInsecureMySQL = 'g̐ݒt@C MySQL ̃ftHgAJEgɑݒ (root [UŃpX[hȂ) ܂܂Ă܂Bg MySQL T[o͂̃ftHgݒœ삵Ă邽ߕsANZX\ȏԂɂȂĂ܂B̃ZLeB[z[͂Ȃ炸Ă';
$strInsertAsNewRow = 'VsƂđ}';
$strInsertedRowId = '}s ID:';
$strInsertedRows = '}s:';
$strInsert = '}';
$strInternalNotNecessary = '* InnoDB ɂ[V݂Ăꍇ͕svł';
$strInternalRelationAdded = '[Vǉ܂';
$strInternalRelations = '[V';
$strInUse = 'gp';
$strInvalidAuthMethod = 'ݒt@CɖȔFؕ@w肳Ă܂:';
$strInvalidColumnCount = 'J 0 傫Ȃ΂܂';
$strInvalidColumn = 'sȃJ(%s)w肳Ă܂!';
$strInvalidCSVFieldCount = 'CSV ͂̃tB[hsł (s: %d)';
$strInvalidCSVFormat = 'CSV ͂̏sł (s: %d)';
$strInvalidCSVParameter = 'CSV C|[g̃p[^sł: %s';
$strInvalidDatabase = 'sȃf[^x[Xł';
$strInvalidFieldAddCount = 'ŒЂƂ̓tB[hǉĂ';
$strInvalidFieldCount = 'e[uɂ͍ŒЂƂ̃tB[hKvł';
$strInvalidLDIImport = '̃vOCł͈kꂽt@C̃C|[g͂ł܂!';
$strInvalidRowNumber = '%d ͕sȍsԍł';
$strInvalidServerHostname = 'T[o %1$s ̃zXgsłBݒmFĂ';
$strInvalidServerIndex = 'T[õCfbNXsł: "%s"';
$strInvalidTableName = 'e[usł';

$strJapanese = '{';
$strJoins = '';
$strJumpToDB = '&quot;%s&quot; f[^x[XɈړ';
$strJustDelete = 'e[u烆[U폜邾ɂ';
$strJustDeleteDescr = '[h܂ł́u폜vꂽ[UӂɃT[oɃANZXł܂';

$strKanjiEncodConvert = 'R[hϊ'; // kanji code convert
$strKeepPass = 'pX[h͕ύXȂ';
$strKeyCache = 'L[LbV';
$strKeyname = 'L[';
$strKill = '~';
$strKnownExternalBug = '%s ̋@\ɂ͊m̃oO܂B%s ';
$strKorean = '؍';

$strLandscape = '';
$strLanguageUnknown = 't@Co^Ă܂: %1$s';
$strLanguage = '';
$strLatchedPages = 'b`Ăy[W';
$strLatexCaption = 'e[ũLvV';
$strLatexContent = 'e[u __TABLE__ ̓e';
$strLatexContinued = '()';
$strLatexContinuedCaption = 'e[ũLvV()';
$strLatexIncludeCaption = 'e[ũLvV܂߂';
$strLatexLabel = 'xL[';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'e[u __TABLE__ ̍\';
$strLatvian = 'grA';
$strLDI = 'LOAD DATA  CSV';
$strLDILocal = 'LOCAL L[[hgp';
$strLengthSet = '/l';
$strLimitNumRows = 'y[W̍s';
$strLinesTerminatedBy = 's̏I[L';
$strLinkNotFound = 'N悪܂';
$strLinksTo = 'N';
$strLithuanian = 'gAjA';
$strLocalhost = '[J';
$strLocationTextfile = 'eLXgt@C̈ʒu';
$strLoginInformation = 'OC';
$strLogin = 'OC';
$strLogout = 'OAEg';
$strLogPassword = 'pX[h:';
$strLogServer = 'T[o';
$strLogUsername = '[U:';
$strLongOperation = '̍Ƃɂ͎Ԃ邱Ƃ܂Bs܂?';

$strMaxConnects = 'ő哯ڑ';
$strMaximalQueryLength = '쐬NG̍ő咷';
$strMaximumSize = 'Œ: %s%s';
$strMbExtensionMissing = 'PHP  mbstring g܂łB}`oCgZbggpĂ悤łAmbstring gȂ phpMyAdmin ͕𐳂łȂߗ\ȂʂɂȂ邱Ƃ܂';
$strMbOverloadWarning = 'PHP ̐ݒ mbstring.func_overload LɂȂĂ܂BphpMyAdmin ͂̃IvVɑΉĂȂ߁Af[^j󂳂邱Ƃ܂!';
$strMIME_available_mime = 'pł MIME ^Cv';
$strMIME_available_transform = 'płϊ@\\';
$strMIME_description = '';
$strMIME_MIMEtype = 'MIME ^Cv';
$strMIME_nodescription = '̕ϊ@\ɂ͐܂B<br />%s ̓ɂĂ͍҂ɂmF';
$strMIME_transformation_note = 'p\ȕϊIvV MIME ^Cv̕ϊ̈ꗗɂĂ %sϊ@\̐%s ';
$strMIME_transformation_options = 'ϊIvV';
$strMIME_transformation_options_note = 'ϊIvV̒l̏: \'a\',\'b\',\'c\'...<br />obNXbV ("\") VONH[g ("\'") lɊ܂߂Kvꍇ ( \\\\xyz  a\\\'b ̂悤) obNXbVŃGXP[vĂ';
$strMIME_transformation = 'uEUϊ@\\';
$strMIMETypesForTable = 'MIME TYPES FOR TABLE'; // XXX
$strMIME_without = 'C^bN\\Ă MIME ^Cvɂ͌ʂ̕ϊ֐͂܂';
$strModifications = 'Cۑ܂';
$strModify = 'C';
$strModifyIndexTopic = 'CfbNXC';
$strMoveMenu = 'j[ړ';
$strMoveTable = 'e[üړ(database<b>.</b>table):';
$strMoveTableOK = 'e[u %s  %s Ɉړ܂';
$strMoveTableSameNames = 'e[uɂ͈ړł܂!';
$strMultilingual = '';
$strMyISAMDataPointerSizeDesc = 'MAX_ROWS IvVw肹 MyISAM e[u쐬Ƃ CREATE TABLE gpftHg̃|C^TCY (oCgP)';
$strMyISAMDataPointerSize = 'f[^|C^̃TCY';
$strMyISAMMaxExtraSortFileSize = 'CfbNX쐬ɗpꎞt@C̍őTCY';
$strMyISAMMaxExtraSortFileSizeDesc = 'MyISAM ̃CfbNXƂɗpꎞt@CƃL[LbV̍Ŏw肵lȏɑ傫Ȃꍇ́AL[LbV@g܂';
$strMyISAMMaxSortFileSizeDesc = 'MyISAM CfbNXč쐬Ƃ (REPAIR TABLE  ALTER TABLEALOAD DATA INFILE ̍Œ) ɗpłꎞt@C̍őTCY';
$strMyISAMMaxSortFileSize = '\[gp̈ꎞt@C̍őTCY';
$strMyISAMRecoverOptions = 'C[h';
$strMyISAMRecoverOptionsDesc = 'NbV MyISAM e[uCƂ̃[h (T[oNIvV --myisam-recover Őݒ肳)';
$strMyISAMRepairThreadsDesc = '̒l 1 傫ꍇ MyISAM e[ũCfbNXCɃ\[gvZXɂ (XbhƂ) 쐬܂';
$strMyISAMRepairThreads = 'Xbh̏C';
$strMyISAMSortBufferSizeDesc = 'REPAIR TABLE ̍Œ MyISAM ̃CfbNX\[gƂA邢 CREATE INDEX  ALTER TABLE ŃCfbNX쐬ƂɊ蓖Ăobt@';
$strMyISAMSortBufferSize = '\[gobt@̃TCY';
$strMySQLCharset = 'MySQL ̕Zbg';
$strMysqlClientVersion = 'MySQL NCAg̃o[W';
$strMySQLConnectionCollation = 'MySQL ̐ڑƍ';
$strMysqlLibDiffersServerVersion = 'g PHP MySQL Cũo[W %s  MySQL T[õo[W %s ƈقȂ܂B͗\ȂsN\܂B';
$strMySQLSaid = 'MySQL̃bZ[W: ';
$strMySQLShowProcess = 'MySQL vZX̕\\';
$strMySQLShowStatus = 'MySQL ̃^C';
$strMySQLShowVars = 'MySQL ̃VXeϐ';

$strName = 'O';
$strNext = '';
$strNoActivity = '%s bȏ㑀܂łBOCȂĂ';
$strNoDatabases = 'f[^x[X݂܂';
$strNoDatabasesSelected = 'f[^x[XIĂ܂';
$strNoDataReceived = 'C|[gf[^Mł܂łBt@CMĂȂAt@CTCY PHP ̐ݒŋꂽől𒴂Ă܂BFAQ 1.16';
$strNoDescription = '܂';
$strNoDetailsForEngine = '̃Xg[WGWɂ̓Xe[^X̏ڍ׏͂܂';
$strNoDropDatabases = 'DROP DATABASE ͖ɂĂ܂';
$strNoExplain = 'SQL  EXPLAIN ͂XLbv';
$strNoFilesFoundInZip = 'ZIP A[JCuɃt@C܂܂Ă܂!';
$strNoFrames = 'phpMyAdmin <b>t[Ή</b>uEUł̗p߂܂';
$strNoIndex = 'CfbNX`Ă܂!';
$strNoIndexPartsDefined = 'CfbNX`Ă܂!';
$strNoModification = 'ύXȂ';
$strNone = 'Ȃ';
$strNoOptions = '̏ɂ̓IvV͂܂';
$strNoPassword = 'pX[hȂ';
$strNoPermission = '̃EFuT[oɂ̓t@C %s ۑ錠܂';
$strNoPhp = 'PHP R[hȗ';
$strNoPrivileges = 'Ȃ';
$strNoRights = 'sŃANZXł܂!';
$strNoRowsSelected = 'sIĂ܂';
$strNo = '';
$strNoSpace = '󂫗eʕsŃt@C %s ۑł܂';
$strNoTablesFound = '̃f[^x[Xɂ̓e[u܂';
$strNoThemeSupport = 'e[}͗pł܂Bݒe[}fBNg %s mFĂ';
$strNotNumber = 'lł͂܂!';
$strNotOK = 'Not OK';
$strNotSet = 'e[u <b>%s</b> ܂B邢 %s ɂ͐ݒ肳Ă܂';
$strNoUsersFound = '[U݂܂';
$strNoValidateSQL = 'SQL ̌؂XLbv';
$strNull = 'k(NULL)';
$strNumberOfFields = 'tB[h';
$strNumberOfTables = 'e[u';
$strNumSearchResultsInTable = '%s ie[u <i>$s</i>)';
$strNumSearchResultsTotal = '<b>v:</b> <i>%s</i> ';
$strNumTables = 'e[u';

$strOK = 'OK';
$strOpenDocumentSpreadsheet = 'XvbhV[gJ';
$strOpenDocumentText = 'eLXgJ';
$strOpenNewWindow = 'ʃEBhEŊJ';
$strOperations = '';
$strOperator = 'Zq';
$strOptimizeTable = 'e[uœK';
$strOptions = 'IvV';
$strOr = '܂';
$strOverhead = 'I[o[wbh';
$strOverwriteExisting = '̃t@C͏㏑';

$strPageNumber = 'y[Wԍ:';
$strPagesToBeFlushed = 'tbV҂y[W';
$strPaperSize = 'pTCY';
$strPartialImport = 'C|[g';
$strPartialText = 'eLXg';
$strPasswordChanged = '%s ̃pX[h͐ύX܂';
$strPasswordEmpty = 'pX[hł!';
$strPasswordHashing = 'pX[hnbV';
$strPasswordNotSame = 'pX[hقȂĂ܂!';
$strPassword = 'pX[h';
$strPdfDbSchema = 'f[^x[X %s ̃XL[} - y[W %s';
$strPdfInvalidTblName = '"%s" e[u݂͑܂!';
$strPdfNoTables = 'e[u܂';
$strPDF = 'PDF';
$strPDFReportExplanation = '(ЂƂ̃e[ũf[^܂ރ|[g𐶐܂)';
$strPDFReportTitle = '|[g̃^Cg';
$strPerHour = '/';
$strPerMinute = '/';
$strPerSecond = '/b';
$strPersian = 'yVA';
$strPhoneBook = 'db';
$strPHP40203 = 'g PHP 4.2.3 ɂ̓}`oCg (mbstring) ̈ɏdȃoO܂BPHP ̃oO|[g 19404 ԂB̃o[W PHP ͂߂ł܂';
$strPhp = 'PHP R[h̍쐬';
$strPHPVersion = 'PHP ̃o[W';
$strPleaseSelectPrimaryOrUniqueKey = 'L[܂̓j[NȃL[IĂ';
$strPmaDocumentation = 'phpMyAdmin ̃hLg';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> ͂Ȃ炸ݒt@CŐݒ肷Kv܂!';
$strPmaWiki = 'phpMyAdmin wiki';
$strPolish = '|[h';
$strPortrait = 'c';
$strPos1 = '擪';
$strPrevious = 'O';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = 'L[폜܂';
$strPrimaryKeyName = 'L[̖O PRIMARY łȂ΂Ȃ܂!';
$strPrimaryKeyWarning = '(L[͂Ȃ炸 "PRIMARY" ƂOłȂ΂Ȃ܂B܂L[ȊO"PRIMARY"ƂOgĂ͂Ȃ܂!)';
$strPrint = '';
$strPrintViewFull = 'p (SeLXg܂)';
$strPrintView = 'p';
$strPrivDescAllPrivileges = 'GRANT ȊÔׂĂ̓t^';
$strPrivDescAlterRoutine = 'XgAh[`̏Cƍ폜';
$strPrivDescAlter = '̃e[u\̕ύX';
$strPrivDescCreateDb = 'Vf[^x[Xe[u̍쐬';
$strPrivDescCreateRoutine = 'XgAh[`̍쐬';
$strPrivDescCreateTbl = 'Ve[u̍쐬';
$strPrivDescCreateTmpTable = 'ꎞe[u̍쐬';
$strPrivDescCreateUser = '[UAJEg̍쐬E폜El[';
$strPrivDescCreateView = 'Vr[̍쐬';
$strPrivDescDelete = 'f[^̍폜';
$strPrivDescDropDb = 'f[^x[Xƃe[u̍폜';
$strPrivDescDropTbl = 'e[u̍폜';
$strPrivDescExecute5 = 'XgAh[`̎s';
$strPrivDescExecute = 'XgA[hvVW̎s (̃o[W MySQL ł͖ł)';
$strPrivDescFile = 'f[^̃C|[gAGNX|[g';
$strPrivDescGrant = 'e[ũ[hȂ̃[UE̒ǉ';
$strPrivDescIndex = 'CfbNX̍쐬A폜';
$strPrivDescInsert = 'f[^̑}Au';
$strPrivDescLockTables = '݂̃Xbh̃e[ubN';
$strPrivDescMaxConnections = 'Pʎԓɉ\ȐVKڑ񐔂𐧌';
$strPrivDescMaxQuestions = 'PʎԓɃT[oɑM\ȃNG𐧌';
$strPrivDescMaxUpdates = 'PʎԓɎs\ȃe[uȂf[^x[X̕ҏWR}h𐧌';
$strPrivDescMaxUserConnections = '[U̓ڑ𐧌';
$strPrivDescProcess3 = '̃[ŨvZX̒~';
$strPrivDescProcess4 = 'vZXꗗŊSȃNG̕\\';
$strPrivDescReferences = '̃o[W MySQL ł͖ł';
$strPrivDescReload = 'T[oݒ̃[hAT[oLbṼtbV';
$strPrivDescReplClient = 'X[u/}X^[̏Ɖ';
$strPrivDescReplSlave = 'vP[VX[uł͗LɂKv܂';
$strPrivDescSelect = 'f[^̓ǂݍ݂';
$strPrivDescShowDb = 'f[^x[Xꗗւ̃ANZX';
$strPrivDescShowView = 'SHOW CREATE VIEW NG̎s';
$strPrivDescShutdown = 'T[õVbg_E';
$strPrivDescSuper = 'őڑɒBĂƂłڑBO[oϐ̐ݒ⑼̃[ŨXbh~ƂǗꍇ͂Ă̐ݒ肪KvɂȂ܂';
$strPrivDescUpdate = 'f[^̏C';
$strPrivDescUsage = '͂܂';
$strPrivileges = '';
$strPrivilegesReloaded = '𐳏Ƀ[h܂';
$strProcedures = 'vVW';
$strProcesses = 'vZX';
$strProcesslist = 'vZXꗗ';
$strProfiling = 'vt@CO';
$strProtocolVersion = 'vgRo[W';
$strPutColNames = '1 sڂɃtB[hǉ';

$strQBEDel = '폜';
$strQBEIns = '}';
$strQBE = 'NG';
$strQueryCache = 'NGLbV';
$strQueryFrame = 'NGEBhE';
$strQueryOnDb = 'f[^x[X <b>%s</b> SQL:';
$strQueryResultsOperations = 'NGʑ';
$strQuerySQLHistory = 'SQL ';
$strQueryStatistics = '<b>NGv</b>: N琔 %s ̃NGT[oɑM܂';
$strQueryTime = 'NG̎s %01.4f b';
$strQueryType = 'NG';
$strQueryWindowLock = '̃EBhENG㏑邱Ƃ͂ł܂';

$strReadRequests = 'ǂݍ݃NGXg';
$strReceived = 'M';
$strRecommended = '';
$strRecords = 'R[h';
$strReferentialIntegrity = 'QƐ̊mF:';
$strRefresh = 'ĕ`';
$strRelationalSchema = '[ViXL[}';
$strRelationDeleted = '[V폜܂';
$strRelationNotWorking = 'Ne[u邽߂̒ǉ@\ɂȂĂ܂BRɂĂ%s%s';
$strRelationsForTable = 'RELATIONS FOR TABLE';
$strRelations = '[V';
$strRelationView = '[Vr[';
$strReload = '[h';
$strReloadingThePrivileges = '[hĂ܂';
$strReloadPrivileges = '[h';
$strRemoveSelectedUsers = 'I[U폜';
$strRenameDatabaseOK = 'f[^x[X %s  %s Ƀl[܂';
$strRenameTable = 'l[̃e[u';
$strRenameTableOK = 'e[u %s  %s Ƀl[܂';
$strRepairTable = 'e[uC';
$strReplaceNULLBy = 'NULL ̑֕';
$strReplaceTable = 'e[uf[^ւt@C';
$strReplication = 'vP[V';
$strReset = 'Zbg';
$strResourceLimits = '\[X̐';
$strRestartInsertion = '%s s}ĊJ';
$strReType = 'x͂Ă';
$strRevoke = '';
$strRevokeAndDelete = 'ׂĎă[U폜';
$strRevokeAndDeleteDescr = 'USAGE ɂĂ͓[h܂Ŏc܂';
$strRevokeMessage = '%s ̓܂';
$strRomanian = '[}jA';
$strRoutineReturnType = 'Ԃl̎';
$strRoutines = '[`';
$strRowLength = 's̒';
$strRowsFrom = 'Jns';
$strRowSize = ' s̃TCY ';
$strRowsModeFlippedHorizontal = ' (wb_])';
$strRowsModeHorizontal = '';
$strRowsModeOptions = '[h: %s (%s ZƂɃwb_\\)';
$strRowsModeVertical = '';
$strRows = 's';
$strRowsStatistic = 's̓v';
$strRunning = 's: %s';
$strRunQuery = 'NGs';
$strRunSQLQuery = 'f[^x[X %s ŃNGs';
$strRunSQLQueryOnServer = 'T[o %s ŃNGs';
$strRussian = 'VA';

$strSaveOnServer = 'T[õfBNg %s ɕۑ';
$strSavePosition = 'ʒuۑ';
$strSave = 'ۑ';
$strScaleFactorSmall = '{邽߃XL[} 1 y[WɎ܂܂';
$strSearchFormTitle = 'f[^x[X';
$strSearchInTables = 'e[u:';
$strSearchNeedle = 'Pl (ChJ[h: "%"):';
$strSearch = '';
$strSearchOption1 = 'ꂩ̒P܂';
$strSearchOption2 = 'ׂĂ̒P܂';
$strSearchOption3 = 'Sv';
$strSearchOption4 = 'K\\';
$strSearchResultsFor = '"<i>%s</i>" ̌ %s:';
$strSearchType = ':';
$strSecretRequired = 'ݒt@C閧̃pXt[Y (blowfish_secret) KvƂ悤ɂȂ܂';
$strSelectADb = 'f[^x[XIĂ';
$strSelectAll = 'SI';
$strSelectBinaryLog = '\\oCiOIĂ';
$strSelectFields = 'tB[hIĂ(Œ1):';
$strSelectForeignKey = 'OL[IĂ';
$strSelectNumRows = 's/NG';
$strSelectReferencedKey = 'QƂĂL[I';
$strSelectTables = 'e[uIĂ';
$strSend = 't@Cɕۑ';
$strSent = 'M';
$strServerChoice = 'T[ȏI';
$strServerNotResponding = 'T[o܂';
$strServerStatus = '^C';
$strServerStatusDelayedInserts = 'xCT[g';
$strServerStatusUptime = ' MySQL T[ỏғ: %s (N: %s)';
$strServers = 'T[o';
$strServerTabVariables = 'ϐ';
$strServer = 'T[o';
$strServerTrafficNotes = '<b>T[ogtBbN</b>: ̕\\ MySQL T[oNȌ̃lbg[NgtBbN̓vł';
$strServerVars = 'T[oϐƐݒl';
$strServerVersion = 'T[õo[W';
$strSessionStartupErrorGeneral = 'G[o߃ZbVJnł܂łBPHP EFuT[õOt@CɏoĂG[mFāAPHP 𐳂ݒ肵ĂB';
$strSessionValue = 'ZbVl';
$strSetEnumVal = 'tB[hʂuenumvȂusetv̏ꍇ̒l̏: \'a\',\'b\',\'c\'...<br />obNXbV("\")VONH[g("\'")܂߂Kvꍇ ( \\\\xyz  a\\\'b ̂悤) ̑OɃobNXbVtĂ';
$strShowAll = 'ׂĕ\\';
$strShowColor = 'F\\';
$strShowDatadictAs = 'f[^`';
$strShowFullQueries = 'NGŜ\\';
$strShowGrid = 'Obh\\';
$strShowHideLeftMenu = '̃j[\\/B';
$strShowingBookmark = '\\̃ubN}[N';
$strShowingPhp = 'PHP R[hƂĕ\\';
$strShowingRecords = '\\̗';
$strShowingSQL = 'SQL NG\\';
$strShowOpenTables = 'JĂe[u\\';
$strShowPHPInfo = 'PHP ';
$strShow = '\\';
$strShowSlaveHosts = 'X[uzXg\\';
$strShowSlaveStatus = 'X[ȕԂ\\';
$strShowStatusBinlog_cache_disk_useDescr = 'ꎞoCiOLbV𗘗p̂ binlog_cache_size ̒l𒴉߂߈ꎞt@CɃXe[ggۑgUNV';
$strShowStatusBinlog_cache_useDescr = 'ꎞoCiOLbVgpgUNV';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Xe[ggsɃT[ofBXNɎꎞe[uBCreated_tmp_disk_tables ̒l傫ꍇ tmp_table_size ̒l𑝂₵ăfBXNł͂ȂɈꎞe[u\z悢܂';
$strShowStatusCreated_tmp_filesDescr = 'mysqld ꎞt@C';
$strShowStatusCreated_tmp_tablesDescr = 'Xe[ggsɃT[öꎞe[u';
$strShowStatusDelayed_errorsDescr = '炩̃G[ (ԂL[̏d)  INSERT DELAYED ꂽs';
$strShowStatusDelayed_insert_threadsDescr = 'gp INSERT DELAYED nh̃XbhBINSERT DELAYED Kpe[u̐ŗL̃Xbhpӂ܂';
$strShowStatusDelayed_writesDescr = 'INSERT DELAYED ŏ܂ꂽs';
$strShowStatusFlush_commandsDescr  = 'FLUSH ̎s';
$strShowStatusHandler_commitDescr = ' COMMIT s';
$strShowStatusHandler_deleteDescr = 'e[us폜';
$strShowStatusHandler_discoverDescr = 'MySQL T[o NDB NX^Xg[WGWɓ̖Oe[uɂĂ̏Ă邩₢킹邱Ƃł܂BJƌ܂AHandler_discover ͂̊Jꂽ^Ce[u̐ł';
$strShowStatusHandler_read_firstDescr = 'CfbNX̍ŏ̃Ggǂݍ񂾉񐔁B̒lꍇ̓T[oxCfbNX̃tXLsĂ̂Ǝv܂BႦ SELECT col1 FROM foo sꍇ (col1 ̓CfbNXɊ܂܂Ă̂Ƃ܂)';
$strShowStatusHandler_read_keyDescr = 'L[ɊÂčsǂݍ񂾃NGXg̐B̒lꍇ̓NGƃe[uK؂ɃCfbNXĂ̂ƍl܂';
$strShowStatusHandler_read_nextDescr = 'L[̏ʂɎ̍sǂݍ񂾃NGXg̐B̒l̓CfbNX̃NGɔ͈͎wĂ邩ACfbNXXLsĂƂɑ܂';
$strShowStatusHandler_read_prevDescr = 'L[̏ʂɑO̍sǂݍ񂾃NGXg̐B̓ǂݍ݂͎ ORDER BY ... DESC ̍œKɗp܂';
$strShowStatusHandler_read_rndDescr = '܂ʒuɍsǂݍ񂾃NGXg̐B̒l̂͌ʂ\[gKvNGʂɎsĂꍇłB炭e[uŜXLȂ΂ȂȂNGʂɍsĂ邩A̍ۂ̃L[̎gɕsK؂ȂƂ낪܂';
$strShowStatusHandler_read_rnd_nextDescr = 'f[^t@C̎̍sǂݍ񂾃NGXg̐B̒l̂̓e[uXLʂɎsĂ邽߂łBʂɂ̓e[ũCfbNXsK؂ANGCfbNX𗘗p悤ɏĂȂƂӖ܂';
$strShowStatusHandler_rollbackDescr = ' ROLLBACK s';
$strShowStatusHandler_updateDescr = 'e[u̍sXVNGXg̐';
$strShowStatusHandler_writeDescr = 'e[uɍs}NGXg̐';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'f[^܂܂y[W̐ (_[eBy[WAN[y[W̕ʂ킸)';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = '݂̃_[eBy[W̐';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'tbVNGXg󂯂obt@v[̃y[W';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = '󂫃y[W';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'InnoDBobt@v[Ńb`Ăy[WB͌ݓǂݍłA邢͏ły[WA邢͑̉炩̗RŃtbV폜łȂȂĂy[W̐ł';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'sbNA_veBunbVCfbNXƂǗI[owbĥŃrW[ɂȂĂy[WB̒lInnodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_dataƂłvZł܂';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'y[W̃obt@v[TCY̍v';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'InnoDBJn_ǂݍ݂̉񐔁B̓NGe[ȗ啔_ȏԂŃXLƂɔ܂';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'InnoDBJnV[PVǂݍ݂̉񐔁BInnoDBV[PVȃte[uXLsƂɔ܂';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'InnoDB s_ǂݍ݃NGXg̐';
$strShowStatusInnodb_buffer_pool_readsDescr = 'InnoDB obt@v[̓e𗘗płAVOy[Wǂݍ݂sȂ΂ȂȂ_ǂݍ݂̉';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'ʏ InnoDB obt@v[ւ݂̏̓obNOEhōs܂Ay[W̓ǂݍ݂Ȃ쐬sKv̂ɃN[ȃy[WȂꍇ́A܂̃y[WtbV̂҂Kv܂B̃JE^́ÃEFCg̉񐔂JEĝłBobt@v[̒lK؂ɐݒ肳Ă΁A̒l͏͂ł';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'InnoDB obt@v[ւ̏݉';
$strShowStatusInnodb_data_fsyncsDescr = '܂ł fsync() s';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'ݕۗĂ fsync() ̉';
$strShowStatusInnodb_data_pending_readsDescr = 'ݕۗĂǂݍ݂̐';
$strShowStatusInnodb_data_pending_writesDescr = 'ݕۗĂ鏑݂̐';
$strShowStatusInnodb_data_readDescr = '܂ł̃f[^ǂݍݗ (P:oCg)';
$strShowStatusInnodb_data_readsDescr = 'f[^ǂݍ݉񐔂̍v';
$strShowStatusInnodb_data_writesDescr = 'f[^݉񐔂̍v';
$strShowStatusInnodb_data_writtenDescr = '܂ł̃f[^̏ݗ (P:oCg)';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'd݂̎s񐔂Ɠd݂y[W';
$strShowStatusInnodb_dblwr_writesDescr = 'd݂̎s񐔂Ɠd݂y[W';
$strShowStatusInnodb_log_waitsDescr = 'Oobt@ătbVȂƍƂ𑱍słȂȂ߂ɔEFCg̉';
$strShowStatusInnodb_log_write_requestsDescr = 'O݃NGXg̐';
$strShowStatusInnodb_log_writesDescr = 'Ot@Cւ݂̉̕';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Ot@Cւ fsync ݂̉';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'ۗ̃Ot@Cւ fsync ';
$strShowStatusInnodb_os_log_pending_writesDescr = 'ۗ̃Ot@Cւ̏݉';
$strShowStatusInnodb_os_log_writtenDescr = 'Ot@Cɏ񂾃oCg';
$strShowStatusInnodb_pages_createdDescr = '쐬ꂽy[W';
$strShowStatusInnodb_page_sizeDescr = 'RpC InnoDB ̃y[WTCY (ftHg:16KB)B̒ly[WPʂŌvZ܂A̒lgΊȒPɃoCgPʂɕϊł܂';
$strShowStatusInnodb_pages_readDescr = 'ǂݍ񂾃y[W';
$strShowStatusInnodb_pages_writtenDescr = '񂾃y[W';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'ݑҋ@̍sbN̐';
$strShowStatusInnodb_row_lock_time_avgDescr = 'sbN擾ɗv镽ώ (P:~b)';
$strShowStatusInnodb_row_lock_timeDescr = 'sbN擾ɗvԂ̍v (P:~b)';
$strShowStatusInnodb_row_lock_time_maxDescr = 'sbN擾ɗvԂ̍ől (P:~b)';
$strShowStatusInnodb_row_lock_waitsDescr = 'sbN擾ɑҋ@';
$strShowStatusInnodb_rows_deletedDescr = 'InnoDB e[u폜s';
$strShowStatusInnodb_rows_insertedDescr = 'InnoDB e[uɑ}s';
$strShowStatusInnodb_rows_readDescr = 'InnoDB e[uǂݍ񂾍s';
$strShowStatusInnodb_rows_updatedDescr = 'InnoDB e[uōXVꂽs';
$strShowStatusKey_blocks_not_flushedDescr = 'ύXĂfBXNɃtbVĂȂL[LbṼL[ubN̐BȑO Not_flushed_key_blocks ł';
$strShowStatusKey_blocks_unusedDescr = 'L[LbV̖gpubN̐BL[LbV̎gp𒲂ׂƂɎg܂';
$strShowStatusKey_blocks_usedDescr = 'L[LbV̎gpς݃ubN̐B̒l͂܂ňxɎgpꂽubN̍ő吔ł';
$strShowStatusKey_read_requestsDescr = 'LbVL[ubNǂݍ񂾃NGXg̐';
$strShowStatusKey_readsDescr = 'fBXNL[ubN𕨗ǂݍ݂񐔁BKey_reads 傫̂͂炭 key_buffer_size 邽߂łBLbV~X̊ Key_reads/Key_read_requests ŌvZł܂';
$strShowStatusKey_write_requestsDescr = 'LbVɃL[ubN񂾃NGXg̐';
$strShowStatusKey_writesDescr = 'fBXNɃL[ubN𕨗݂';
$strShowStatusLast_query_costDescr = 'NGIveB}CU[̌vZɂAŌɃRpCꂽNG̑RXgBNG̃vςƂɃRXgǂς邩rƂɕ֗łBftHgl 0 ͂܂xNGRpCĂȂƂӖł';
$strShowStatusNot_flushed_delayed_rowsDescr = 'INSERT DELAYED L[̒ŏ܂̂҂Ăs';
$strShowStatusOpened_tablesDescr = 'JĂe[u̐BJĂe[uꍇ͂炭e[uLbV̒l܂';
$strShowStatusOpen_filesDescr = 'JĂt@C̐';
$strShowStatusOpen_streamsDescr = 'JĂXg[̐ (ɃŐL^pł)';
$strShowStatusOpen_tablesDescr = 'JĂe[u̐';
$strShowStatusQcache_free_blocksDescr = 'NGLbV̋󂫃ubN̐';
$strShowStatusQcache_free_memoryDescr = 'NGLbV̋󂫃';
$strShowStatusQcache_hitsDescr = 'LbṼqbg';
$strShowStatusQcache_insertsDescr = 'LbVɒǉꂽNG̐';
$strShowStatusQcache_lowmem_prunesDescr = 'VNGLbV邽߂ɃׂLbV폜ꂽNG̐B̏̓NGLbṼTCY𒲐Ƃɕ֗łBNGLbV͍ŌɎgꂽłÂ̂폜(LRU)헪ɏ]č폜NG߂܂';
$strShowStatusQcache_not_cachedDescr = 'LbVȂ (LbVłȂ query_cache_type ̐ݒŃLbVȂƂɂȂĂ) NG̐';
$strShowStatusQcache_queries_in_cacheDescr = 'LbVɓo^ĂNG̐';
$strShowStatusQcache_total_blocksDescr = 'NGLbV̑ubN';
$strShowStatusReset = 'Zbg';
$strShowStatusRpl_statusDescr = 'tFCZ[tvP[V̏ ()';
$strShowStatusSelect_full_joinDescr = 'CfbNX𗘗pȂ̐B̒l 0 łȂꍇ̓e[ũCfbNX悭mFĂ';
$strShowStatusSelect_full_range_joinDescr = 'Qƃe[uŔ͈͌̐';
$strShowStatusSelect_range_checkDescr = 'L[w肳ĂȂ߈sL[gĂ邩mF̐i0 łȂꍇ̓e[ũCfbNX悭mFĂj';
$strShowStatusSelect_rangeDescr = 'ŏ̃e[uŔ͈͎w肳ꂽ̐ (̒l͑傫Ăӂ肠܂)';
$strShowStatusSelect_scanDescr = 'ŏ̃e[utXL̐';
$strShowStatusSlave_open_temp_tablesDescr = 'X[u SQL Xbh݊JĂꎞe[u̐';
$strShowStatusSlave_retried_transactionsDescr = 'vP[VX[u SQL XbhgUNVĎs(N̍v)';
$strShowStatusSlave_runningDescr = '̃T[o}X^[ɐڑX[ułꍇ ON ɂȂ܂';
$strShowStatusSlow_launch_threadsDescr = 'slow_launch_time Ŏw肳ꂽbȏɍ쐬ԂXbh̐';
$strShowStatusSlow_queriesDescr = 'long_query_time Ŏw肳ꂽbȏɎԂ̂NG̐';
$strShowStatusSort_merge_passesDescr = '\[gASYsȂ΂ȂȂ}[W̉񐔁B̒lꍇ sort_buffer_size VXeϐ̒l𑝂₵悢ł傤';
$strShowStatusSort_rangeDescr = '͈͎wtŃ\[gsꂽ';
$strShowStatusSort_rowsDescr = '\[gς̍s';
$strShowStatusSort_scanDescr = 'e[uXLƂɎsꂽ\[g̉';
$strShowStatusTable_locks_immediateDescr = 'e[ubNɎ擾ł';
$strShowStatusTable_locks_waitedDescr = 'e[ubNɎ擾łEFCg񐔁B̒lAptH[}Xɖ肪Ăꍇ́A܂NGœKĂBł߂Ȃe[u𕪊邩AvP[V𗘗pĂ';
$strShowStatusThreads_cachedDescr = 'XbhLbṼXbhBLbṼqbg Threads_created/Connections ŌvZł܂B̒lԂȂĂꍇ thread_cache_size 傫Ă';
$strShowStatusThreads_connectedDescr = '݊JĂڑ̐';
$strShowStatusThreads_createdDescr = 'ڑ̂߂ɍ쐬ꂽXbh̐BThreads_created 傫ꍇ thread_cache_size ̒l𑝂₵悢܂ (Xbh̎ɖ肪Ȃꍇ͂ӂ܂ptH[}X͌サ܂)';
$strShowStatusThreads_runningDescr = 'X[vĂȂXbh̐';
$strShowTableDimension = 'e[ȗ傫\\';
$strShowTables = 'e[u\\';
$strShowThisQuery = ' sNGɕ\\';
$strSimplifiedChinese = 'ȑ̎';
$strSingly = '(1 )';
$strSize = 'TCY';
$strSkipQueries = '擪琔XLbv郌R[h(NG)̐';
$strSlovak = 'XoLA';
$strSlovenian = 'XxjA';
$strSmallBigAll = 'ׂĂ傫/';
$strSnapToGrid = 'Obhɂ킹';
$strSocketProblem = '(邢̓[J MySQL T[õ\Pbgݒ肳Ă܂)';
$strSortByKey = 'L[Ń\[g';
$strSort = '\[g';
$strSorting = '\[g';
$strSpaceUsage = 'fBXNgp';
$strSpanish = 'XyC';
$strSplitWordsWithSpace = 'eP͋󔒕(" ")ŋ؂Ă';
$strSQLCompatibility = 'SQL݊[h';
$strSQLExportType = 'GNX|[g`';
$strSQLParserBugMessage = 'SQL p[TɃoO邱Ƃ肦܂A܂̓NG悭Ĉp̐ނɊԈႢȂmFĂBNH[gĂȂeLXg̈ɃoCit@CAbv[hNGsƂƂ肦܂BMySQL ̃R}hCC^tF[X𗘗păNGsĂ݂Ă悢ł傤B MySQL T[õG[o͂oĂ悤Ȃ̉͂ɖ𗧂܂BłȂAR}hCł͐̂Ƀp[Tł͎sꍇ́ASQL NG̓̓f[^ۂɖNĂNGЂƂɍi荞łAȉ́uCUTvZNVɃf[^YăoO񍐂𑗂Ă:';
$strSQLParserUserError = 'SQL ɃG[悤łB MySQL T[õG[o͂oĂ悤Ȃ̉͂ɖ𗧂܂';
$strSQLQuery = 's SQL';
$strSQLResult = 'SQL ̌';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'sȎʎqł';
$strSQPBugUnclosedQuote = 'pĂ܂';
$strSQPBugUnknownPunctuation = 'ȋǓ_ł';
$strStandInStructureForView = 'r[p̑֍\';
$strStatCheckTime = 'ŏI';
$strStatCreateTime = '쐬';
$strStatement = 'Xe[gg';
$strStatisticsOverrun = 'WT[oł̓oCgJE^߂邱Ƃ邽߁AMySQL T[o񍐂Ă铝v͕smȂƂ܂';
$strStatUpdateTime = 'ŏIXV';
$strStatus = '';
$strStorageEngines = 'Xg[WGW';
$strStorageEngine = 'Xg[WGW';
$strStrucCSV = 'CSV f[^';
$strStrucData = '\ƃf[^';
$strStrucExcelCSV = 'MS Excel p CSV';
$strStrucNativeExcel = 'MS Excel ̃lCeBu`';
$strStrucOnly = '\̂';
$strStructPropose = 'e[u\mF';
$strStructure = '\';
$strStructureForView = 'r[p̍\';
$strSubmit = 's';
$strSuccess = 'SQL ͐Ɏs܂';
$strSum = 'v';
$strSwedish = 'XEF[f';
$strSwitchToDatabase = 'Rs[f[^x[Xɐ؂ւ';
$strSwitchToTable = 'Rs[e[uɐ؂ւ';

$strTableAlreadyExists = 'e[u %s ͊ɑ݂܂!';
$strTableComments = 'e[ũRg';
$strTableEmpty = 'e[uł!';
$strTable = 'e[u';
$strTableHasBeenDropped = 'e[u %s 폜܂';
$strTableHasBeenEmptied = 'e[u %s ɂ܂';
$strTableHasBeenFlushed = 'e[u %s tbV܂';
$strTableIsEmpty = 'e[û悤ł!';
$strTableMaintenance = 'e[uǗ';
$strTableName = 'e[u';
$strTableOfContents = 'e[u̓e';
$strTableOptions = 'e[uIvV';
$strTables = '%s e[u';
$strTableStructure = 'e[u̍\';
$strTakeIt = 'ɂ';
$strTblPrivileges = 'e[uŗL̓';
$strTempData = 'ꎞf[^';
$strTextAreaLength = ' ɂĂ͂̃tB[h<br /> CłȂȂꍇ܂';
$strThai = '^C';
$strThemeDefaultNotFound = 'ftHge[} %s ܂!';
$strTheme = 'e[} / X^C';
$strThemeNoPreviewAvailable = 'vr[͗pł܂';
$strThemeNotFound = 'e[} %s ܂!';
$strThemeNoValidImgPath = 'e[} %s ̉摜pXł!';
$strThemePathNotFound = 'e[} %s ̃e[}pX܂!';
$strThisHost = '̃zXg';
$strThreadSuccessfullyKilled = 'Xbh %s ͐I܂';
$strThreads = 'Xbh';
$strTime = '';
$strTimeoutInfo = 'ÕC|[g̓^CAEg܂BđMƈʒu %d ĊJ܂';
$strTimeoutNothingParsed = 'AŌɎsƂ͂܂f[^͂ł܂łBӂ PHP ̎ԐL΂Ȃ肱̃f[^̃C|[g͂ł܂';
$strTimeoutPassed = 'XNvg^CAEg܂BC|[ĝłΓt@CđM΃C|[gĊJ܂';
$strToFromPage = 'Jn/Iy[W';
$strToggleScratchboard = 'XNb`{[h؂ւ';
$strToggleSmallBig = '召؂ւ';
$strToSelectRelation = '[VI܂:';
$strTotalUC = 'v';
$strTotal = 'v';
$strTraditionalChinese = 'ɑ̎';
$strTraditionalSpanish = 'XyC (`\\L)';
$strTraffic = 'gtBbN';
$strTransactionCoordinator = 'gUNVR[fBl[^';
$strTransformation_application_octetstream__download = 'tB[h̃oCif[^_E[h郊N\\܂B1 ڂ̃IvVɃoCit@C̃t@Cw肷邱Ƃł܂A2 ڂ̃IvVɃt@CێĂtB[h̖OnƂł܂B2 ڂ̃IvVgꍇ 1 ڂ̃IvV͋󕶎ɂKv܂';
$strTransformation_application_octetstream__hex = 'f[^ 16 iŕ\\L܂BIvVƂčŏ̃p[^ɃXy[Xǉpxw肷邱Ƃł܂ (ftHg 2 juƂł)';
$strTransformation_image_jpeg__inline = 'NbN\ȃTlC\\܂; IvVƂĕƍ̍őlsNZPʂŎwł܂BAXyNg͂̂܂܈ێ܂';
$strTransformation_image_jpeg__link = '̉摜_E[h邽߂̃N\\܂';
$strTransformation_image_png__inline = 'image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'TIMEATIMESTAMPADATETIMEA邢Unix^CX^v̒lĂtB[hɂ킹ĕ\\܂B1 ڂ̃IvV̓^CX^vɉZ鎞ł(ftHg: 0)B2 ڂ̃IvVɂ͓̏w肵܂B3 ڂ̃IvV̓[J̓Ƃ݂Ȃ UTC Ƃ݂Ȃł ("local"Ȃ"utc"Ƃw肵Ă)B̒lɂē̕\\Lς܂B"local" ̏ꍇ PHP  strftime() ֐̐B"utc" ̏ꍇ gmdate() 𗘗p܂'; // XXX replaced
$strTransformation_text_plain__external = 'LINUX ̂: OAvP[VNĕW͌oRŃtB[hf[^n܂BAvP[V̕Wo͂Ԃ܂BftHg Tidy ł ( HTML R[hYɂ邽߂̂̂ł)BZLeB̗R libraries/transformations/text_plain__external.inc.php ŕҏWėpc[𖾋LĂKv܂Bŏ̃IvV͗pvO̐ŁA2 ڂ̃IvV̓vÕp[^łB3 ڂ̃IvV 1 ɐݒ肳Ăꍇ htmlspecialchars() pďo͂ϊ܂(ftHg 1 ł)B4 ڂ̃IvV 1 ɐݒ肳Ăꍇ֑͋o͑Ŝ 1 sɎ܂悤ɂ܂ (ftHg 1 ł)';
$strTransformation_text_plain__formatted = 'tB[h̓ê܂܁Ahtmlspecialchars()ʂɕ\\܂B̏ꍇAtB[hɂ͐ HTML ܂܂Ă̂Ɖ肵܂';
$strTransformation_text_plain__imagelink = '摜ƃN\\܂BtB[hɂ̓t@CĂB1 ڂ̃IvV "http://domain.com/" ̂悤URL̐擪łB2 ڂ3 ڂ̃IvVɂ͕ƍsNZPʂŎw肵܂';
$strTransformation_text_plain__link = 'N\\܂BtB[hɂ̓t@CĂB1 ڂ̃IvV "http://domain.com/" ̂悤 URL ̐擪A2 ڂ̃IvV̓Ñ^Cgł';
$strTransformation_text_plain__sql = 'eLXg̓e SQL NGƂ݂ȂA\nCCg\\܂';
$strTransformation_text_plain__substr = '̈ꕔ݂̂\\܂B1 ڂ̃IvV͕̐擪牽XLbv邩 (ftHg 0 ł)A2 ڂ̃IvV͕\\eLXg̕ł (ftHg͕̖܂łł)B3 ڂ̃IvV͕؂l߂ƂɑO^ɕ₤ȗLł (ftHg ... ł)';
$strTriggers = 'gK';
$strTruncateQueries = 'NG̕\\؂l߂';
$strTurkish = 'gR';
$strType = '';

$strUkrainian = 'ENCi';
$strUncheckAll = 'ׂẴ`FbNO';
$strUnicode = 'UNICODE';
$strUnique = 'j[N';
$strUnknown = 's';
$strUnselectAll = 'SI';
$strUnsupportedCompressionDetected = 'T|[gĂȂk`(%s)̃t@C[h悤Ƃ܂B̌`̓T|[gĂȂݒŖɂĂ܂';
$strUpdatePrivMessage = '%s ̓XV܂';
$strUpdateProfileMessage = 'vt@CXV܂';
$strUpdateQuery = 'NGXV';
$strUpdComTab = 'column_comments e[u̍XV@ɂĂ̓hLg';
$strUpgrade = '%s  %s ȍ~ɃAbvO[hĂ';
$strUploadErrorCantWrite = 't@CfBXNɏ߂܂B';
$strUploadErrorExtension = 'ĝŃt@C̃Abv[hf܂B';
$strUploadErrorFormSize = 'Abv[ht@C HTML tH[Ɏw肳Ă MAX_FILE_SIZE fBNeBu̒l𒴂Ă܂B';
$strUploadErrorIniSize = 'Abv[ht@C php.ini Ɏw肳Ă upload_max_filesize fBNeBu̒l𒴂Ă܂B';
$strUploadErrorNoTempDir = 'ꎞtH_܂B';
$strUploadErrorPartial = 'Abv[ht@C͈ꕔAbv[hł܂łB';
$strUploadErrorUnknown = 't@C̃Abv[hɗ\ȂG[܂B';
$strUploadLimit = 'Abv[h悤Ƃt@C傫悤łB΍ɂĂ %shLg%s ';
$strUploadsNotAllowed = '̃T[oł̓t@C̃Abv[h͂ł܂';
$strUsage = 'gp';
$strUseBackquotes = 'e[utB[htNH[gň͂';
$strUsedPhpExtensions = 'gp PHP g';
$strUseHostTable = 'zXge[ug';
$strUserAlreadyExists = '[U %s ͊ɑ݂܂!';
$strUserEmpty = '[Uł!';
$strUserName = '[U';
$strUserNotFound = 'e[uɂ͑I[U܂';
$strUserOverview = '[UT';
$strUsersDeleted = 'I[U𐳂폜܂';
$strUsersHavingAccessToDb = '&quot;%s&quot; ɃANZXł郆[U';
$strUser = '[U';
$strUseTabKey = '̒lɈړƂ TAB L[gĂBCTRL{J[\L[gƎRɈړł܂';
$strUseTables = 'pe[u';
$strUseTextField = 'eLXgtB[h̒l𗘗p';
$strUseThisValue = '̒l𗘗p';

$strValidateSQL = 'SQL ̌';
$strValidatorError = 'SQL ̌؋@\ł܂B%shLg%s ̋LڒʂɕKv PHP gCXg[Ă邩mFĂ';
$strValue = 'l';
$strVar = 'ϐ';
$strVersionInformation = 'o[W';
$strViewDumpDatabases = 'f[^x[X̃_v(XL[})\\';
$strViewDumpDB = 'DB ̃_v(XL[})\\';
$strViewDump = 'e[ũ_v(XL[})\\';
$strViewHasBeenDropped = 'r[ %s j܂';
$strViewMaxExactCount = 'r[̍s %s z܂B%shLg%s ';
$strViewName = 'VIEW ̖O';
$strView = 'r[';

$strWebServerUploadDirectory = 'EFuT[õAbv[hfBNg';
$strWebServerUploadDirectoryError = 'w肵Abv[hfBNgpł܂';
$strWelcome = '%s ւ悤';
$strWestEuropean = '[bp';
$strWildcard = 'ChJ[h';
$strWindowNotFound = '^[QbgƂȂuEUEBhEXVł܂łBeEBhEAuEŨZLeBݒŃNXEBhE̍XVubNĂ̂Ǝv܂';
$strWithChecked = '`FbN̂:';
$strWriteRequests = '݃NGXg';
$strWrongUser = '[UȂpX[hԈĂ܂B<br />ANZX͋ۂ܂';

$strXkana = 'SpJi֕ϊ'; // convert to X208-kana
$strXML = 'XML';

$strYes = '͂';

$strZeroRemovesTheLimit = ': IvV 0 ([)ɐݒ肷Ɛ܂';
$strZip = '"zip `"';

$strSuhosin = 'Suhosin gݍ܂Ă邽ߖ肪\܂Bڂ %sdocumentation%s B';  
?>
